/// <reference types="react" />
import * as typeIs from './typeIs';
/**
 * Utility for making it easier to couple a React Component to a css selector.
 * Useful when writing css selectors that rely on interactivity, i.e. :hover.
 * Example:
 *  const checkBoxWrapper = createDataProp('checkbox-wrapper');
 *  // Used as selector:
 *  css`&:hover ${checkboxWrapper.selector} { }`
 *  // Used on React Component
 *  <div {...checkboxWrapper.prop} />
 * @param {string} name Name of element we want to reference.
 */
export declare function createDataProp(name: string): {
    prop: {
        [x: string]: string;
    };
    selector: string;
};
/** Helper type to extract an HTML element's valid props */
export declare type HTMLElementProps<Element extends keyof JSX.IntrinsicElements> = JSX.IntrinsicElements[Element] extends React.DetailedHTMLProps<infer Props, any> ? Props : never;
export { typeIs };
